@@ -4,9 +4,9 @@ Demo_DAWGI_HBM
 Age-metallicity inference of a simple stellar population.
 """
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __author__ = 'Jairo Andrés Alzate Trujillo'
 __credits__ = 'Instituto de Radioastronómia y Astrofísica, Universidad Nacional Autónoma de México'
 
-from . import SFH_Sampling
-__all__ = ['SFH_Sampling']
+from . import (SFH_Sampling, SFH_3D_plot_no_scaled, a_statistics_def_fun, Marginal_SFH_Bar_NoScale)
+__all__ = ['SFH_Sampling', 'SFH_3D_plot_no_scaled', 'a_statistics_def_fun', 'Marginal_SFH_Bar_NoScale']
